import React from "react";
import type { Moment } from 'moment';
export interface SortProps extends SortContentProps {
    /** 排序条件缓存key值，默认'sort' */
    cacheKey?: string;
    /** 卡片类名 */
    overlayClassName?: string;
    /** 卡片样式 */
    overlayStyle?: string;
    /** 展开行为， 可选'hover' | 'focus' | 'click' | 'contextMenu' */
    trigger?: string | string[];
    /** 排序按钮文案，默认“排序” */
    btnText?: string;
    /** 自定义排序按钮 */
    btnRender?: React.ReactNode;
    /** 条件选择后的回调，默认失焦触发 */
    ok?: (sortParmas: FieldsType | []) => void;
    /** 排序字段数据 */
    items?: ItemType[];
    /** 默认排序条件 */
    defaultFields?: FieldsType;
    /** 按钮样式 */
    style?: React.CSSProperties;
    /** 是否展示自动排序开关 */
    showAutoSortButton?: boolean;
    /** 是否默认打开自动排序开关 */
    isAutoSort?: boolean;
}
export declare type FieldType = 'selection' | 'string' | 'number' | 'date' | 'address' | 'org' | 'emp' | 'object';
/** 最终搜索入参类型 */
export interface SortParamsType {
    /** 字段ID */
    fieldId: string;
    /** 输入框value值 */
    sortOrder: string;
}
export interface ItemType {
    fieldId: string;
    fieldName?: string;
    multiSelect?: boolean;
    sortStrategy?: {
        label: string;
        value: string;
    }[];
    [key: string]: any;
}
export declare type ItemsMapType = Map<string, Omit<ItemType, 'selection' | 'showOption' | 'placeholder'>>;
export interface SortContentProps {
    /** 主标题文案 */
    sortTitle?: React.ReactNode;
    /** 主标题副文案 */
    sortSecondTitle?: React.ReactNode;
    /** 是否展示自动排序开关 */
    showAutoSortButton?: boolean;
    /** 是否默认打开自动排序开关 */
    isAutoSort?: boolean;
}
/** 从Form表单中获取到的数据类型 */
export declare type FieldsType = {
    fieldName?: string;
    fieldId: string;
    sortOrder: [Moment, Moment] | string | string[] | number | {
        label: string;
        value: string;
    }[];
}[];
