import React, { ReactNode } from 'react';
import type { IdType, RenderModuleType, ValueTypeType, SortOrderType, FixedType, InfosType } from './base';
import type { OnChangeType, EditChangeType } from './function';
import type { TableRefType } from './refs';
import type { DPPickerProps } from '../../DPPicker';
import type { CCProps } from '../../CostCenterPicker';
import type { Service } from 'ahooks/lib/useRequest/src/types.d';
import type { CascaderProps } from 'rlj-design';
import type { AttachmentUploadProps } from '../../AttachmentUpload';
interface CCPropsWithoutApi extends Omit<CCProps, 'apiList' | 'apiSearch' | 'onCancel' | 'onOk' | 'open'> {
    type?: DPPickerProps['type'];
    effectDateKey?: string;
}
interface DPPickerPropsWithoutApi extends Omit<DPPickerProps, 'selectDept' | 'searchDeptChain' | 'searchPersonChain' | 'type' | 'onCancel' | 'onOk' | 'open'> {
    type?: DPPickerProps['type'];
    effectDateKey?: string;
}
declare type AddressCascaderProps = CascaderProps & {
    addressLevel?: number | string;
    action?: Service<unknown, any[]>;
};
export type { OnChangeType, EditChangeType, InfosType, TableRefType };
export declare type TableUnit = {
    [key: IdType]: any;
    expandShowIcon?: boolean;
    expand?: boolean;
    children?: Array<TableUnit>;
    expandStatus?: boolean;
};
export interface TableColumns<T> {
    dataIndex?: keyof T;
    title: string | (() => ReactNode);
    width?: number;
    minWidth?: number;
    fixed?: FixedType;
    valueType?: ValueTypeType;
    selection?: {
        label: string;
        value: React.Key;
        key?: React.Key;
    }[];
    selectionAsync?: {
        emptyText?: (errorInfo: any) => ReactNode | string;
        isLoadingClose?: boolean;
        data?: (data: string, record: T) => Promise<{
            label: string;
            value: string;
        }[]>;
    };
    disabled?: boolean;
    disabledReason?: string;
    iconConfig?: {
        icon?: ReactNode;
        onClick?: (colUnit: T) => void;
        width?: number;
    };
    info?: (text: any, record: T, index: number, width: number) => React.ReactNode;
    className?: string;
    hidden?: boolean;
    resize?: boolean;
    paddingLeft?: number;
    paddingRight?: number;
    required?: boolean;
    show?: boolean;
    sorter?: boolean;
    sortOrder?: SortOrderType;
    expandCol?: boolean;
    cCPickerProps?: CCPropsWithoutApi;
    dPPickerProps?: DPPickerPropsWithoutApi;
    addressProps?: AddressCascaderProps;
    attachmentUploadProps?: AttachmentUploadProps;
    renderModule?: RenderModuleType;
    children?: TableColumns<T>[];
    render?: (text: any, record: T, index: number, width: number) => React.ReactNode;
    mergeId?: string;
    fold?: boolean;
    foldInfo?: {
        baseKey: string;
        firstCol: boolean;
        lastCol: boolean;
    };
    firstCol?: boolean;
    lastCol?: boolean;
    rowSelectionIconSp?: boolean;
    father?: {
        data: TableColumns<T>;
        index: number;
        firstCol: boolean;
        lastCol: boolean;
    };
}
export interface ISummation<T> {
    show?: boolean;
    data?: T;
    remark?: string;
}
export interface TableProps<T> {
    rowKey?: string;
    className?: string;
    height?: number;
    maxHeight?: number;
    width?: number;
    itemHeight?: number;
    itemWidth?: number;
    defaultShowCtx?: string;
    crosswalk?: boolean;
    loading?: boolean;
    columns: Array<TableColumns<T>>;
    dataSource: Array<T>;
    summation?: ISummation<T>;
    renderModule?: RenderModuleType;
    expandConfig?: {
        expandKey?: string;
        onExpandChange?: (key: string) => Promise<T>;
        defaultExpand?: number;
    };
    onChange?: OnChangeType;
    rowSelection?: {
        selectedRowKeys: Array<string>;
        onChange: (data: string[], type?: true | false | undefined) => void;
        rowSelectionIconSp?: boolean;
    };
    pagination?: {
        total?: number;
        pageSize?: number;
        current?: number;
        onChange?: (current: number, pageSize: number) => void;
        onShowSizeChange?: (current: number, pageSize: number) => void;
    };
    editableConfig?: {
        showColExtraHeader?: boolean;
        editable?: boolean;
        onEditChange?: EditChangeType;
        selectRowShowDel?: boolean;
        delCb?: (dataRowId: string, data: T) => void;
        showAddBtn?: boolean;
        addCb?: () => Promise<{
            [key in IdType]: any;
        }>;
        customizeConfig?: {
            visible: boolean;
            onCustomizeChange: (dataIndex: string, dataRowId: string, data: T, column: TableColumns<T>) => void;
        };
        infos?: InfosType[];
        disabled?: InfosType[];
        addressProps?: AddressCascaderProps;
        cCPickerProps?: Omit<CCProps, 'onCancel' | 'onOk' | 'open'> & {
            effectDateKey?: string;
        };
        dPPickerProps?: Omit<DPPickerProps, 'type' | 'onCancel' | 'onOk' | 'open'> & {
            effectDateKey?: string;
        };
        attachmentUploadProps?: AttachmentUploadProps;
    };
}
declare global {
    interface Window {
        tExcelResize: boolean;
    }
}
