import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import { getPrimary } from "../utils/tools";
import { Dropdown, Icon } from 'rlj-design';
import "./index.less";
import { ExcelContext } from "../index";
export var TYPE = {
  header: Symbol(),
  ctx: Symbol()
};
export var MODE = {
  diamond: Symbol(),
  checked: Symbol(),
  unChecked: Symbol()
};
export default function Checked(props) {
  var _ref = useContext(ExcelContext),
      columnInfo = _ref.columnInfo;

  var type = props.type,
      _props$rowSelection = props.rowSelection,
      rowSelection = _props$rowSelection === void 0 ? {} : _props$rowSelection,
      _props$dataSource = props.dataSource,
      dataSource = _props$dataSource === void 0 ? [] : _props$dataSource,
      _props$data = props.data,
      data = _props$data === void 0 ? {} : _props$data,
      _props$rowKey = props.rowKey,
      rowKey = _props$rowKey === void 0 ? 'id' : _props$rowKey;

  var _ref2 = rowSelection || {},
      _ref2$selectedRowKeys = _ref2.selectedRowKeys,
      selectedRowKeys = _ref2$selectedRowKeys === void 0 ? [] : _ref2$selectedRowKeys,
      _ref2$onChange = _ref2.onChange,
      onChange = _ref2$onChange === void 0 ? function () {} : _ref2$onChange,
      rowSelectionIconSp = _ref2.rowSelectionIconSp; // 防止 null


  var idsAll = useMemo(function () {
    return type === TYPE.ctx ? [] : Array.from(new Set(dataSource.map(function (v) {
      return typeof rowKey === 'function' ? rowKey(v) : v[rowKey];
    })));
  }, [dataSource]);

  var getId = function getId() {
    return typeof rowKey === 'function' ? rowKey(data) : data[rowKey];
  };

  var mode = Symbol();

  if (type === TYPE.header) {
    var tmp = selectedRowKeys.filter(function (v) {
      return idsAll.includes(v);
    });

    if (tmp.length === idsAll.length) {
      mode = MODE.checked;
    } else if (tmp.length) {
      mode = MODE.diamond;
    }
  } else if (type === TYPE.ctx) {
    if (selectedRowKeys.includes(getId())) {
      mode = MODE.checked;
    }
  }

  var handleCheck = function handleCheck() {
    if (type === TYPE.header) {
      if (mode === MODE.diamond) {
        onChange(idsAll);
      } else if (mode === MODE.checked) {
        onChange([]);
      } else {
        onChange(idsAll);
      }
    } else if (type === TYPE.ctx) {
      if (mode === MODE.checked) {
        onChange(selectedRowKeys.filter(function (v) {
          return v !== getId();
        }));
      } else {
        var _tmp = [].concat(selectedRowKeys);

        _tmp.push(getId());

        onChange(_tmp);
      }
    }
  };

  var menuClick = function menuClick(param) {
    if (type === TYPE.header) {
      var key = param.key;

      if (key === '1') {
        onChange(idsAll, true);
      }

      if (key === '2') {
        onChange(idsAll, false);
      }

      if (key === '3') {
        onChange([]);
      }
    }
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(CheckBox, {
    value: mode,
    disabled: type === TYPE.header && columnInfo.isEmptyData,
    onChange: handleCheck
  }), rowSelectionIconSp && type === TYPE.header && /*#__PURE__*/React.createElement(Dropdown, {
    trigger: ['click'],
    disabled: rowSelectionIconSp && type === TYPE.header && columnInfo.isEmptyData,
    menu: {
      items: [{
        key: 1,
        label: '选择全部'
      }, {
        key: 2,
        label: '选择当前页'
      }, {
        key: 3,
        label: '取消全选'
      }],
      onClick: menuClick
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "iconRowSelectionSp"
  }, /*#__PURE__*/React.createElement(Icon, {
    type: "dropDownArrowDown",
    size: 12
  }))));
}
export var CheckBox = function CheckBox(props) {
  var value = props.value,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled;

  var CheckBoxRender = function CheckBoxRender(_ref3) {
    var style = _ref3.style;
    return /*#__PURE__*/React.createElement("div", {
      onClick: onChange,
      style: style !== null && style !== void 0 ? style : {},
      className: getPrimary(classnames('tExcel-checkbox', {
        diamond: value === MODE.diamond,
        checked: value === MODE.checked
      }))
    });
  };

  var DisabledRender = function DisabledRender(_ref4) {
    var children = _ref4.children;
    return /*#__PURE__*/React.createElement("div", {
      style: {
        cursor: 'not-allowed'
      }
    }, children);
  }; // 禁用


  if (disabled) {
    return /*#__PURE__*/React.createElement(DisabledRender, {
      children: /*#__PURE__*/React.createElement(CheckBoxRender, {
        style: {
          pointerEvents: 'none',
          background: '#ececed',
          cursor: 'not-allowed'
        }
      })
    });
  } else {
    return /*#__PURE__*/React.createElement(CheckBoxRender, null);
  }
};