import React, { useContext } from 'react';
import classnames from 'classnames';
import { Resizable } from 'react-resizable';
import { foldWidth, sorterWidth, extraIconWidth, foldKeySuffix } from "../../utils/config";
import { getMinWidth, createCellPos, getKey } from "../../utils/tools";
import Ellipsis from "../../components/Ellipsis";
import { Icon } from 'rlj-design';
import Checked, { TYPE as CheckType } from "../../Checked";
import "./item.less";
import { ExcelContext } from "../../index";
import { Tooltip } from 'antd';
var touchStartLeft = -1;
export default (function (props) {
  var _ref = useContext(ExcelContext),
      _ref$rowKey = _ref.rowKey,
      rowKey = _ref$rowKey === void 0 ? 'id' : _ref$rowKey,
      rowSelection = _ref.rowSelection,
      dataSource = _ref.dataSource,
      moveLine = _ref.moveLine,
      excelBox = _ref.excelBox,
      salaryBox = _ref.salaryBox,
      editableConfig = _ref.editableConfig,
      selectRow = _ref.selectRow,
      changeColumns = _ref.changeColumns,
      colData = _ref.colData,
      columnInfo = _ref.columnInfo;

  var index = props.index,
      style = props.style,
      mainColumns = props.mainColumns,
      isFixCol = props.isFixCol;
  var subColumns = mainColumns.children,
      resize = mainColumns.resize;

  var _ref2 = editableConfig || {},
      editable = _ref2.editable,
      showColExtraHeader = _ref2.showColExtraHeader; // 默认的高度样式


  var defaultStyle = {
    height: colData.defaultItemHeight
  };
  var defaultRowSpanStyle = {
    height: colData.defaultItemHeight * 2
  };
  /**
   * 修改表头的状态, 折叠和排序
   */

  var changeColumn = function changeColumn(childIndex, value, type) {
    return function (e) {
      e.stopPropagation();
      changeColumns(index, childIndex, value, type);
    };
  };
  /**
   * 标图图标，排序图标和折叠图标，svg
   * @param item
   * @param isSpFoldCol
   */


  var renderIcon = function renderIcon(item, isSpFoldCol) {
    var sorter = item.sorter,
        sortOrder = item.sortOrder,
        fold = item.fold,
        iconConfigSource = item.iconConfig,
        disabled = item.disabled,
        disabledReason = item.disabledReason;
    var iconConfig = iconConfigSource; // 如果当前列别禁用, 并且有报错原因, 则拦截iconConfig, 右边显示一个禁用提示文案

    if (disabled && disabledReason) {
      iconConfig = {
        icon: /*#__PURE__*/React.createElement(Tooltip, {
          title: disabledReason
        }, /*#__PURE__*/React.createElement(Icon, {
          type: 'warningAreality'
        }))
      };
    }

    return /*#__PURE__*/React.createElement("div", {
      className: classnames('iconSpBox', {
        iconSpBoxRelative: isSpFoldCol
      })
    }, iconConfig && /*#__PURE__*/React.createElement("div", {
      className: "iconExtraClass",
      style: {
        width: iconConfig.width || extraIconWidth
      }
    }, /*#__PURE__*/React.createElement("span", {
      style: {
        cursor: 'pointer',
        fontSize: 14,
        color: '#c8c8cb'
      },
      onClick: function onClick() {
        var _iconConfig, _iconConfig$onClick;

        return (_iconConfig = iconConfig) === null || _iconConfig === void 0 ? void 0 : (_iconConfig$onClick = _iconConfig.onClick) === null || _iconConfig$onClick === void 0 ? void 0 : _iconConfig$onClick.call(_iconConfig, item);
      }
    }, iconConfig.icon || /*#__PURE__*/React.createElement(Icon, {
      type: 'moreVertical'
    }))), sorter && /*#__PURE__*/React.createElement("div", {
      className: "iconCaret"
    }, sortOrder === 'ascend' ? /*#__PURE__*/React.createElement(Icon, {
      type: "ascendingOrder",
      size: 16
    }) : sortOrder === 'descend' ? /*#__PURE__*/React.createElement(Icon, {
      type: "reverseOrder",
      size: 16
    }) : /*#__PURE__*/React.createElement(Icon, {
      type: "defaultOrder",
      size: 16,
      color: "#c1c1c4"
    })), fold !== undefined && /*#__PURE__*/React.createElement("div", {
      className: "iconFold",
      onClick: changeColumn('main', !fold, 'fold')
    }, fold ? /*#__PURE__*/React.createElement(Icon, {
      type: "unfold"
    }) : /*#__PURE__*/React.createElement(Icon, {
      type: "stow"
    })));
  };
  /**
   * 获取新的排序方式，在三种排序方式（默认、正序、倒叙）中切换
   * @param sortOrder
   */


  var getSortOrder = function getSortOrder(sortOrder) {
    var sortValue = undefined;

    if (!sortOrder) {
      sortValue = 'ascend';
    } else if (sortOrder === 'ascend') {
      sortValue = 'descend';
    }

    return sortValue;
  };

  var renderContent = function renderContent(param) {
    if (param.text === 'rowSelectionChecked') {
      return /*#__PURE__*/React.createElement(Checked, {
        rowKey: rowKey,
        type: CheckType.header,
        rowSelection: rowSelection,
        dataSource: dataSource
      });
    }

    var style = {};
    if (param.paddingLeft) style.paddingLeft = param.paddingLeft;
    if (param.paddingLeft) style.paddingRight = param.paddingRight;

    if (typeof param.text === 'function') {
      return param.text(param.width);
    }

    var isShowRequired = (editableConfig === null || editableConfig === void 0 ? void 0 : editableConfig.editable) && param.required;
    return /*#__PURE__*/React.createElement("div", {
      style: style,
      className: classnames(param.className, {
        requireAsterisk: isShowRequired
      })
    }, /*#__PURE__*/React.createElement(Ellipsis, {
      text: param.text,
      width: param.width - (isShowRequired ? 9 : 0),
      isMaxWidth: true
    }));
  };

  var handleSorter = function handleSorter(props) {
    return function (e) {
      var sorter = props.sorter,
          sortOrder = props.sortOrder,
          changeIndex = props.changeIndex;
      if (!sorter) return;
      changeColumn(changeIndex, getSortOrder(sortOrder), 'sort')(e);
    };
  }; // =============================================== 父项和子项 ===============================================

  /**
   * 父项-第一行
   */


  var renderMain = function renderMain(param) {
    var _getKey, _father$data, _father$data$children;

    var mainTitle = param.title,
        sorter = param.sorter,
        fold = param.fold,
        sortOrder = param.sortOrder,
        _param$paddingLeft = param.paddingLeft,
        paddingLeft = _param$paddingLeft === void 0 ? 0 : _param$paddingLeft,
        _param$paddingRight = param.paddingRight,
        paddingRight = _param$paddingRight === void 0 ? 0 : _param$paddingRight,
        valueType = param.valueType,
        iconConfig = param.iconConfig,
        dataIndex = param.dataIndex,
        father = param.father;
    var notResizeCol = isFixCol || resize === false; //是否可拖拽, 固定列和明确表示不能缩放的列, true => 不能拖拽

    var widthAssist = paddingLeft + paddingRight; //额外的宽度

    var isNumber = valueType === 'int' || valueType === 'number'; // 是否数字

    var isSpFoldCol = (_getKey = getKey(param)) === null || _getKey === void 0 ? void 0 : _getKey.includes(foldKeySuffix);
    var isFoldCol = param.foldInfo;
    var isNeedAssist = !(father !== null && father !== void 0 && (_father$data = father.data) !== null && _father$data !== void 0 && (_father$data$children = _father$data.children) !== null && _father$data$children !== void 0 && _father$data$children.every(function (v) {
      return v.hidden;
    }));
    var rowSpan = !father && columnInfo.hierarchy === 2 || !isNeedAssist;

    var item = function item() {
      var ctxWidth = style.width - 20;
      var className = '';

      if (fold !== undefined) {
        ctxWidth -= foldWidth;
      }

      if (sorter) {
        ctxWidth -= sorterWidth;
      }

      if (widthAssist) {
        ctxWidth -= widthAssist;
      }

      if (iconConfig) {
        ctxWidth -= iconConfig.width || extraIconWidth;
      }

      if (!sorter && fold === undefined && isNumber) {
        className += ' int-value-style';
      }

      return /*#__PURE__*/React.createElement("div", {
        className: classnames('salaryExcelColumnsItemInner', {
          delPadding: isSpFoldCol,
          sort: sorter,
          lastColHiddenBorder: param.lastCol,
          salaryExcelHeaderFold: isFoldCol,
          salaryExcelHeaderHighlight: selectRow && selectRow.currentColumn.dataIndex === dataIndex
        }),
        onClick: handleSorter({
          sorter: sorter,
          sortOrder: sortOrder,
          changeIndex: 'main'
        }),
        style: rowSpan ? defaultRowSpanStyle : defaultStyle
      }, !isSpFoldCol && renderContent({
        text: mainTitle,
        width: ctxWidth,
        paddingLeft: paddingLeft,
        paddingRight: paddingRight,
        className: className,
        required: param.required
      }), renderIcon(param, isSpFoldCol));
    };

    var itemAssist = function itemAssist() {
      if (!!father && isNeedAssist) {
        var _father$data$title;

        return /*#__PURE__*/React.createElement("div", {
          className: classnames('salaryExcelColumnsItemInner', {
            delPadding: isSpFoldCol,
            lastColHiddenBorder: param.lastCol || !father.lastCol
          }),
          style: defaultStyle
        }, father.index === 0 && renderContent({
          text: (_father$data$title = father === null || father === void 0 ? void 0 : father.data.title) !== null && _father$data$title !== void 0 ? _father$data$title : '',
          width: style.width - 20
        }));
      } else {
        return null;
      }
    };

    return /*#__PURE__*/React.createElement(React.Fragment, null, itemAssist(), !notResizeCol ? renderResize(item(), getKey(param), 'main', param) : item());
  }; // =============================================== 父子组合-二行-最终渲染 ===============================================


  var renderHeaderExcelRow = function renderHeaderExcelRow() {
    if (!editable || showColExtraHeader === false) return;
    return /*#__PURE__*/React.createElement("div", {
      className: classnames('fatherBoxFather', {
        fatherBoxFatherFirst: index === 0,
        lastColHiddenBorder: mainColumns.lastCol
      }),
      style: defaultStyle
    }, createCellPos(index - 1));
  };

  var concatMainSub = function concatMainSub() {
    return /*#__PURE__*/React.createElement("div", {
      className: classnames('salaryExcelColumnsItem')
    }, renderHeaderExcelRow(), renderMain(mainColumns));
  }; // =============================================== 可拖拽item ===============================================


  var renderResize = function renderResize(children, id, type, item) {
    return /*#__PURE__*/React.createElement(Resizable, {
      key: id,
      width: style.width + 1,
      height: 0 //设置一个0，高度不重要，高度不会变, 未来需求可能需要变化
      ,
      onResize: handleResize(type, item),
      onResizeStart: handleResizeStart(type),
      onResizeStop: handleResizeStop(type, item),
      draggableOpts: {
        enableUserSelectHack: false
      }
    }, /*#__PURE__*/React.createElement("div", null, children));
  };

  var setMoveLine = function setMoveLine(pageX) {
    if (salaryBox.current && moveLine.current) {
      var _salaryBox$current$ge = salaryBox.current.getBoundingClientRect(),
          height = _salaryBox$current$ge.height,
          top = _salaryBox$current$ge.top;

      moveLine.current.style.top = "".concat(top + 1, "px");
      moveLine.current.style.height = "".concat(height, "px");
      moveLine.current.style.left = pageX + 'px';
      moveLine.current.style.display = 'block';
    }
  };

  var getSourceWidth = function getSourceWidth(changeIndex) {
    var sourceWidth;

    if (changeIndex === 'main') {
      sourceWidth = mainColumns.width;
    } else {
      sourceWidth = subColumns[changeIndex].width;
    }

    return sourceWidth;
  };

  var handleResize = function handleResize(changeIndex, item) {
    return function (e) {
      if (moveLine.current) {
        var sourceWidth = getSourceWidth(changeIndex); // 限制拖拽的最小宽度，并且不能在拖拽后表头的总宽度小于表格的最大宽度，
        // data的curMaxWidth是根据纵向是否有滚动条，计算好的值

        if (e.pageX - touchStartLeft + sourceWidth >= getMinWidth(item) && columnInfo.lenRus + e.pageX - touchStartLeft >= columnInfo.curMaxWidth) {
          setMoveLine(e.pageX);
        }
      }
    };
  };

  var handleResizeStart = function handleResizeStart() {
    return function (e) {
      touchStartLeft = e.pageX;
      window.tExcelResize = true; //阻止超长省略组件hover触发

      if (excelBox.current) {
        excelBox.current.style.userSelect = 'none';
        setMoveLine(e.pageX);
      }
    };
  };

  var handleResizeStop = function handleResizeStop(changeIndex, item) {
    return function (e) {
      window.tExcelResize = false; //允许超长省略组件hover触发

      var sourceWidth = getSourceWidth(changeIndex);
      var widthPre = Math.floor(e.pageX - touchStartLeft + sourceWidth);
      var minWidth = getMinWidth(item); // 拖拽后的表头总宽度比表格的宽度小

      if (columnInfo.lenRus + e.pageX - touchStartLeft <= columnInfo.curMaxWidth) {
        var tmp = sourceWidth - (columnInfo.lenRus - columnInfo.curMaxWidth);
        minWidth = tmp > minWidth ? tmp : minWidth;
      }

      var width = widthPre < minWidth ? minWidth : widthPre;

      if (width !== sourceWidth) {
        changeColumns(index, changeIndex, width, 'width');
      }

      touchStartLeft = -1;

      if (moveLine.current) {
        moveLine.current.style.display = 'none';
      }

      if (excelBox.current) {
        excelBox.current.style.userSelect = 'text';
      }
    };
  }; // =============================================== render ===============================================


  return /*#__PURE__*/React.createElement("div", {
    style: style
  }, concatMainSub());
});