import React, { useContext, useRef } from 'react';
import { Resizable } from 'react-resizable';
import classnames from 'classnames';
import { ExcelContext } from "../../index";
export default function Crosshair(props) {
  var rowIndex = props.rowIndex,
      currentColumn = props.currentColumn,
      currentData = props.currentData,
      top = props.top,
      left = props.left,
      width = props.width;

  var _ref = useContext(ExcelContext),
      colData = _ref.colData,
      dataSource = _ref.dataSource,
      changeTable = _ref.changeTable,
      excelBox = _ref.excelBox,
      dragLine = _ref.dragLine,
      selectRow = _ref.selectRow;

  var rowHeight = colData.defaultItemHeight;
  var startY = useRef(0);
  var sourceMaxIndex = dataSource && dataSource.length - 1;

  var resizeStart = function resizeStart(e) {
    startY.current = e.pageY;

    if (excelBox) {
      excelBox.current.style.userSelect = 'none';
    }

    if (dragLine) {
      try {
        var target = document.querySelector('.salaryExcelDataItemSelect');

        if (target) {
          var _target$getBoundingCl = target.getBoundingClientRect(),
              _top = _target$getBoundingCl.top,
              _left = _target$getBoundingCl.left,
              _width = _target$getBoundingCl.width;

          var dragLineDom = dragLine.current;
          dragLineDom.style.display = 'block';
          dragLineDom.style.top = _top + rowHeight + 'px';
          dragLineDom.style.left = _left + 'px';
          dragLineDom.style.width = _width + 'px';
          dragLineDom.style.height = '0px';
        }
      } catch (e) {
        throw e;
      }
    }
  };

  var resizeStop = function resizeStop(e) {
    if (excelBox) {
      excelBox.current.style.userSelect = 'auto';
    }

    if (dragLine) {
      var dragLineDom = dragLine.current;
      dragLineDom.style.display = 'none';
    }

    var maxRowIndex = Math.ceil((e.pageY - startY.current) / rowHeight) + rowIndex;
    changeTable({
      data: {
        rowIndex: rowIndex,
        maxRowIndex: maxRowIndex > sourceMaxIndex ? sourceMaxIndex : maxRowIndex,
        style: selectRow === null || selectRow === void 0 ? void 0 : selectRow.style
      },
      currentColumn: currentColumn,
      currentData: currentData
    }, 'copyDrags');
  };

  var resize = function resize(e) {
    if (dragLine) {
      var maxRowIndex = Math.ceil((e.pageY - startY.current) / rowHeight);

      if (e.target.className.includes('salaryExcelDataItem')) {
        var dragLineDom = dragLine.current;
        dragLineDom.style.height = maxRowIndex * rowHeight + 'px';
      }
    }
  };

  return /*#__PURE__*/React.createElement(Resizable, {
    key: "crosshair",
    width: 8,
    height: 8,
    onResize: resize,
    onResizeStart: resizeStart,
    onResizeStop: resizeStop,
    draggableOpts: {
      enableUserSelectHack: false
    }
  }, /*#__PURE__*/React.createElement("span", {
    className: classnames('dataItemCrosshair', {
      lastCol: currentColumn.lastCol
    }),
    style: {
      top: top,
      left: currentColumn.lastCol ? left - width + 3 : left
    }
  }));
}